<?php

declare(strict_types=1);

namespace Test\Test\Domain\Model;


/**
 * This file is part of the "Test" Extension for TYPO3 CMS.
 *
 * For the full copyright and license information, please read the
 * LICENSE.txt file that was distributed with this source code.
 *
 * (c) 2021 
 */

/**
 * Product
 */
class Product extends \TYPO3\CMS\Extbase\DomainObject\AbstractEntity
{

    /**
     * title
     *
     * @var string
     */
    protected $title = '';

    /**
     * color
     *
     * @var \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Test\Test\Domain\Model\Color>
     */
    protected $color = null;

    /**
     * Returns the title
     *
     * @return string $title
     */
    public function getTitle()
    {
        return $this->title;
    }

    /**
     * Sets the title
     *
     * @param string $title
     * @return void
     */
    public function setTitle(string $title)
    {
        $this->title = $title;
    }

    /**
     * __construct
     */
    public function __construct()
    {

        // Do not remove the next line: It would break the functionality
        $this->initializeObject();
    }

    /**
     * Initializes all ObjectStorage properties when model is reconstructed from DB (where __construct is not called)
     * Do not modify this method!
     * It will be rewritten on each save in the extension builder
     * You may modify the constructor of this class instead
     *
     * @return void
     */
    public function initializeObject()
    {
        $this->color = $this->color ?: new \TYPO3\CMS\Extbase\Persistence\ObjectStorage();
    }

    /**
     * Adds a Color
     *
     * @param \Test\Test\Domain\Model\Color $color
     * @return void
     */
    public function addColor(\Test\Test\Domain\Model\Color $color)
    {
        $this->color->attach($color);
    }

    /**
     * Removes a Color
     *
     * @param \Test\Test\Domain\Model\Color $colorToRemove The Color to be removed
     * @return void
     */
    public function removeColor(\Test\Test\Domain\Model\Color $colorToRemove)
    {
        $this->color->detach($colorToRemove);
    }

    /**
     * Returns the color
     *
     * @return \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Test\Test\Domain\Model\Color> $color
     */
    public function getColor()
    {
        return $this->color;
    }

    /**
     * Sets the color
     *
     * @param \TYPO3\CMS\Extbase\Persistence\ObjectStorage<\Test\Test\Domain\Model\Color> $color
     * @return void
     */
    public function setColor(\TYPO3\CMS\Extbase\Persistence\ObjectStorage $color)
    {
        $this->color = $color;
    }
}
